@@ -217,12 +217,21 @@ print.nnetarmodels <- function(x, ...)
 }
 
 
-forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), xreg=NULL, lambda=object$lambda, ...)
+forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), PI=FALSE, level=c(80, 95), fan=FALSE, xreg=NULL, lambda=object$lambda, bootstrap=FALSE, npaths=1000, innov=NULL, ...)
 {
 #  require(nnet)
   out <- object
   tspx <- tsp(out$x)
-
+  #
+  if(fan)
+    level <- seq(51,99,by=3)
+  else
+  {
+    if(min(level) > 0 & max(level) < 1)
+      level <- 100*level
+    else if(min(level) < 0 | max(level) > 99.99)
+      stop("Confidence limit out of range")
+  }
   # Check if xreg was used in fitted model
   if(is.null(object$xreg))
   {
@@ -263,11 +272,45 @@ forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), xr
     fcast[i] <- mean(sapply(object$model, predict, newdata=newdata))
     flag <- c(fcast[i],flag[-maxlag])
   }
+  # Re-scale point forecasts
   if(!is.null(object$scalex))
     fcast <- fcast * object$scalex$scale + object$scalex$center
-  out$mean <- ts(fcast,start=tspx[2]+1/tspx[3],frequency=tspx[3])
+  # Add ts properties
+  fcast <- ts(fcast,start=tspx[2]+1/tspx[3],frequency=tspx[3])
+  # Back-transform point forecasts
   if(!is.null(lambda))
-    out$mean <- InvBoxCox(out$mean,lambda)
+    fcast <- InvBoxCox(fcast,lambda)
+  # Compute prediction intervals using simulations
+  if(isTRUE(PI))
+  {
+    nint <- length(level)
+    sim <- matrix(NA,nrow=npaths,ncol=h)
+    if(!is.null(innov))
+    {
+      if(length(innov) != h*npaths)
+        stop("Incorrect number of innovations, need h*npaths values")
+      innov <- matrix(innov, nrow=h, ncol=npaths)
+      bootstrap <- FALSE
+    }
+    for(i in 1:npaths)
+      sim[i,] <- simulate(object, nsim=h, bootstrap=bootstrap, xreg=xreg, lambda=lambda, innov=innov[, i], ...)
+    lower <- apply(sim, 2, quantile, 0.5 - level/200, type = 8)
+    upper <- apply(sim, 2, quantile, 0.5 + level/200, type = 8)
+    if (nint > 1L) {
+      lower <- t(lower)
+      upper <- t(upper)
+    }
+  }
+  else
+  {
+    level <- NULL
+    lower <- NULL
+    upper <- NULL
+  }
+  out$mean <- fcast
+  out$level <- level
+  out$lower <- lower
+  out$upper <- upper
   return(structure(out,class="forecast"))
 }
 
