@@ -81,15 +81,13 @@ myarima.sim <- function (model, n, x, e, ...)
     data <- ts(data,frequency=1,start=1)
   if (!is.list(model))
     stop("'model' must be list")
+  if(n <= 0L)
+    stop("'n' must be strictly positive")
   p <- length(model$ar)
-  if (p)
-  {
-    minroots <- min(Mod(polyroot(c(1, -model$ar))))
-    if (minroots <= 1)
-      stop("'ar' part of model is not stationary")
-  }
   q <- length(model$ma)
   d <- 0
+  D <- model$seasonal.difference
+  m <- model$seasonal.period
   if (!is.null(ord <- model$order))
   {
     if (length(ord) != 3L)
@@ -102,6 +100,12 @@ myarima.sim <- function (model, n, x, e, ...)
     if (d != round(d) || d < 0)
       stop("number of differences must be a positive integer")
   }
+  if (p)
+  {
+    minroots <- min(Mod(polyroot(c(1, -model$ar))))
+    if (minroots <= 1)
+      stop("'ar' part of model is not stationary")
+  }
   if (length(model$ma))
   {
     #MA filtering
@@ -113,16 +117,16 @@ myarima.sim <- function (model, n, x, e, ...)
 
   if(length(model$ar) & (len.ar <= length(data)))
   {
-    if((model$seasonal.difference != 0) && (d != 0))
+    if((D != 0) && (d != 0))
     {
       diff.data <- diff(data, lag=1, differences = d)
-      diff.data <- diff(diff.data, lag=model$seasonal.period, differences = model$seasonal.difference)
+      diff.data <- diff(diff.data, lag=m, differences = D)
     }
-    else if((model$seasonal.difference != 0) && (d == 0))
+    else if((D != 0) && (d == 0))
     {
-      diff.data <- diff(data, lag=model$seasonal.period, differences = model$seasonal.difference)
+      diff.data <- diff(data, lag=model$seasonal.period, differences = D)
     }
-    else if((model$seasonal.difference == 0) && (d != 0))
+    else if((D == 0) && (d != 0))
       diff.data <- diff(data, lag=1, differences = d)
     else
       diff.data <- data
@@ -134,7 +138,7 @@ myarima.sim <- function (model, n, x, e, ...)
     {
       lagged.x.values <- x.with.data[(i-len.ar):(i-1)]
       ar.coefficients <- model$ar[length(model$ar):1]
-      sum.multiplied.x <- sum((lagged.x.values * ar.coefficients)[abs(ar.coefficients) < 1e-13])
+      sum.multiplied.x <- sum((lagged.x.values * ar.coefficients)[abs(ar.coefficients) > .Machine$double.eps])
       x.with.data[i] <- x.with.data[i]+sum.multiplied.x
     }
 
@@ -147,7 +151,7 @@ myarima.sim <- function (model, n, x, e, ...)
     #AR filtering for all other cases where AR is used.
     x <- stats::filter(x, model$ar, method = "recursive")
   }
-  if((d == 0) && (model$seasonal.difference == 0) && (flag.noadjust==FALSE)) # Adjust to ensure end matches approximately
+  if((d == 0) && (D == 0) && (flag.noadjust==FALSE)) # Adjust to ensure end matches approximately
   {
     # Last 20 diffs
     if(n.start >= 20)
@@ -165,52 +169,39 @@ myarima.sim <- function (model, n, x, e, ...)
   {
     x <- x[-(1:n.start)]
   }
-  ##
-  #####
-  #Seasonal undifferencing, if there is no regular differencing
-  if((model$seasonal.difference > 0) && (d == 0))
+
+
+  ########Undo all differences
+
+  if((D > 0) && (d == 0))
   {
-    i <- length(data)-model$seasonal.difference*model$seasonal.period+1
+    #Seasonal undifferencing, if there is no regular differencing
+    i <- length(data) - D*m + 1
     seasonal.xi <- data[i:length(data)]
     length.s.xi <- length(seasonal.xi)
-    x <- diffinv(x, lag=model$seasonal.period, differences=model$seasonal.difference, xi=seasonal.xi)[-(1:length.s.xi)]
-    data.new <- data
+    x <- diffinv(x, lag=m, differences=D, xi=seasonal.xi)[-(1:length.s.xi)]
   }
-  else
+  else if((d > 0) && (D == 0))
   {
-    data.new <- data
+    #Regular undifferencing, if there is no seasonal differencing
+    x <- diffinv(x, differences=d, xi=data[length(data)-(d:1)+1])[-(1:d)]
   }
-  ###End seasonal undifferencing
-
-  ##Regular undifferencing, if there is no seasonal differencing
-  if (d > 0 && (model$seasonal.difference == 0))
+  else if((d > 0) && (D > 0))
   {
-  x <- diffinv(x, differences = d,xi=data.new[length(data.new)-(d:1)+1])[-(1:d)]
-  }
-
-  ########
-  #Code for Undifferencing for where the differencing is both Seasonal and Non-Seasonal (Non-Seasonal First)
-  #Regular first
-  if((d > 0) && (model$seasonal.difference > 0))
-  {
-    delta.four <- diff(data, lag=model$seasonal.period, differences = model$seasonal.difference)
-    regular.xi <- delta.four[(length(delta.four)-model$seasonal.difference):length(delta.four)]
+    #Undifferencing for where the differencing is both Seasonal and Non-Seasonal
+    #Regular first
+    delta.four <- diff(data, lag=m, differences=D)
+    regular.xi <- delta.four[(length(delta.four)-D):length(delta.four)]
     x <- diffinv(x, differences = d, xi=regular.xi[length(regular.xi)-(d:1)+1])[-(1:d)]
-  }
-
-  #Then seasonal
-  if((model$seasonal.difference > 0) && (d > 0))
-  {
-    i <- length(data)-model$seasonal.difference*model$seasonal.period+1
+ 
+    #Then seasonal
+    i <- length(data) - D*m + 1
     seasonal.xi <- data[i:length(data)]
     length.s.xi <- length(seasonal.xi)
-    x <- diffinv(x, lag=model$seasonal.period, differences=model$seasonal.difference, xi=seasonal.xi)
+    x <- diffinv(x, lag=m, differences=D, xi=seasonal.xi)
     x <- x[-(1:length.s.xi)]
-    data.new <- data
   }
 
-  ########
-
   x <- ts(x[1:n],frequency=frequency(data),start=tsp(data)[2]+1/tsp(data)[3])
   return(x)
 }
@@ -277,8 +268,8 @@ simulate.Arima <- function(object, nsim=length(object$x), seed=NULL, xreg=NULL,
 
     if(future)
     {
-      model <- list(order=order, ar=ar, ma=ma,sd=sqrt(object$sigma2),residuals=residuals(object), 
-        seasonal.difference=object$arma[7], seasonal.period=object$arma[5], flag.seasonal.arma=flag.s.arma, 
+      model <- list(order=order, ar=ar, ma=ma,sd=sqrt(object$sigma2),residuals=residuals(object),
+        seasonal.difference=object$arma[7], seasonal.period=object$arma[5], flag.seasonal.arma=flag.s.arma,
         seasonal.order=object$arma[c(3,7,4)])
     }
     else
@@ -306,7 +297,7 @@ simulate.Arima <- function(object, nsim=length(object$x), seed=NULL, xreg=NULL,
 
     if(future)
     {
-      model <- list(order=object$arma[c(1, 6, 2)],ar=ar,ma=ma,sd=sqrt(object$sigma2),residuals=residuals(object), 
+      model <- list(order=object$arma[c(1, 6, 2)],ar=ar,ma=ma,sd=sqrt(object$sigma2),residuals=residuals(object),
         seasonal.difference=0, flag.seasonal.arma=flag.s.arma, seasonal.order=c(0,0,0), seasonal.period=1)
     }
     else
@@ -437,7 +428,7 @@ simulate.ar <- function(object, nsim=object$n.used, seed=NULL, future=TRUE, boot
   else if(length(innov)==nsim)
     e <- innov
   else
-    stop("Length of innov must be equal to nsim")  
+    stop("Length of innov must be equal to nsim")
   if(future)
     return(myarima.sim(model,nsim,x=object$x,e=e) + x.mean)
   else
@@ -448,16 +439,16 @@ simulate.fracdiff <- function(object, nsim=object$n, seed=NULL, future=TRUE, boo
 {
   x <- getResponse(object)
 
-  # Strip initial and final missing values 
-  xx <- na.ends(x) 
+  # Strip initial and final missing values
+  xx <- na.ends(x)
   n <- length(xx)
 
   # Remove mean
   meanx <- mean(xx)
-  xx <- xx - meanx 
+  xx <- xx - meanx
 
   # Difference series (removes mean as well)
-  y <- undo.na.ends(x, diffseries(xx, d = object$d)) 
+  y <- undo.na.ends(x, diffseries(xx, d = object$d))
 
   # Create ARMA model for differenced series
   arma <- Arima(y, order = c(length(object$ar), 0, length(object$ma)),
@@ -471,5 +462,93 @@ simulate.fracdiff <- function(object, nsim=object$n, seed=NULL, future=TRUE, boo
 }
 
 
-
-
+simulate.nnetar <- function(object, nsim=length(object$x), seed=NULL, xreg=NULL, future=TRUE, bootstrap=FALSE, innov=NULL, lambda=object$lambda, ...)
+{
+  if(is.null(innov))
+  {
+    if (!exists(".Random.seed", envir = .GlobalEnv, inherits = FALSE))
+      runif(1)
+    if (is.null(seed))
+      RNGstate <- get(".Random.seed", envir = .GlobalEnv)
+    else
+    {
+      R.seed <- get(".Random.seed", envir = .GlobalEnv)
+      set.seed(seed)
+      RNGstate <- structure(seed, kind = as.list(RNGkind()))
+      on.exit(assign(".Random.seed", R.seed, envir = .GlobalEnv))
+    }
+  }
+  ## only future currently implemented
+  if(!future)
+    warning("simulate.nnetar() currently only supports future=TRUE")
+  ## set simulation innovations
+  if(bootstrap)
+  {
+    res <- na.omit(residuals(object))/object$scalex$scale
+    e <- sample(res,nsim,replace=TRUE)
+  }
+  else if(is.null(innov))
+  {
+    res <- na.omit(residuals(object))/object$scalex$scale
+    e <- rnorm(nsim, 0, sd(res, na.rm=TRUE))
+  }
+  else if(length(innov)==nsim)
+    e <- innov/object$scalex$scale
+  else if(length(innov)==1)
+    e <- rep(innov, nsim)/object$scalex$scale
+  else
+    stop("Length of innov must be equal to nsim")
+  ##
+  tspx <- tsp(object$x)
+  # Check if xreg was used in fitted model
+  if(is.null(object$xreg))
+  {
+    if(!is.null(xreg))
+      warning("External regressors were not used in fitted model, xreg will be ignored")
+    xreg <- NULL
+  }
+  else
+  {
+    if(is.null(xreg))
+      stop("No external regressors provided")
+    xreg <- as.matrix(xreg)
+    if(NCOL(xreg) != NCOL(object$xreg))
+      stop("Number of external regressors does not match fitted model")
+    if(NROW(xreg) != nsim)
+      stop("Number of rows in xreg does not match nsim")
+  }
+  xx <- object$x
+  if(!is.null(lambda))
+  {
+    xx <- BoxCox(xx,lambda)
+  }
+  # Check and apply scaling of fitted model
+  if(!is.null(object$scalex))
+  {
+    xx <- scale(xx, center = object$scalex$center, scale = object$scalex$scale)
+    if(!is.null(xreg))
+      xreg <- scale(xreg, center = object$scalexreg$center, scale = object$scalexreg$scale)
+  }
+  ## Get lags used in fitted model
+  lags <- object$lags
+  maxlag <- max(lags)
+  flag <- rev(tail(xx, n=maxlag))
+  ## Simulate by iteratively forecasting and adding innovation
+  path <- numeric(nsim)
+  for (i in 1:nsim){
+    newdata <- c(flag[lags], xreg[i, ])
+    if(any(is.na(newdata)))
+      stop("I can't simulate when there are missing values near the end of the series.")
+    path[i] <- mean(sapply(object$model, predict, newdata=newdata)) + e[i]
+    flag <- c(path[i],flag[-maxlag])
+  }
+  ## Re-scale simulated points
+  if(!is.null(object$scalex))
+    path <- path * object$scalex$scale + object$scalex$center
+  ## Add ts properties
+  path <- ts(path,start=tspx[2]+1/tspx[3],frequency=tspx[3])
+  ## Back-transform simulated points
+  if(!is.null(lambda))
+    path <- InvBoxCox(path,lambda)
+  return(path)
+}
